<div style="margin-bottom: 2em;">
  <button id="startdesigner" class="btn btn-primary btn-block">
    {$lang['designnow']}
    <i class="fas fa-paint-roller"></i>
  </button>
</div>
<style>
  html.designer {
    overflow: hidden;
  }

  .splash {
    background-color: #ffffff;
    opacity: 0;
    position: fixed;
    left: 0;
    top: 0;
    bottom: 0;
    right: 0;
    height: 100vh;
    z-index: 10000;
    transition: opacity 0.25s ease-in-out;
  }

  .splash.show {
    opacity: 1;
    transition: opacity 0.25s ease-in-out;
  }

  .splash .inner {
    left: 50%;
    position: relative;
    top: 50%;
    transform: translate(-50%, -50%);
    width: 250px;
  }

  .splash .inner .progressbar {
    border: 1px solid #888888;
    border-radius: 2.5px;
    height: 5px;
    left: 0;
    margin-top: 3px;
    position: relative;
    width: 100%;
  }

  .splash .inner .progressbar .indicator {
    background-color: #e87d0c;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 0;
  }
</style>
<script>
  'use strict';
  var assetpath = '{$assetpath}';
  var fontPath = '{$fontPath}';
  var kArtikel = {$kArtikel};
  var lang = {$langJSON};
  var totalpreloadsize = {$totalpreloadsize};
  var svgIcons = {$svgIconsJSON};
  var version = '{$pluginversion}';
  var splashLogo = {$splashLogo};
  {literal}
    var scripts = [
      'ButtonBar',
      'ChunkyUpload',
      'ColorPicker',
      'fabric',
      'FileSaver',
      'fontfaceobserver',
      'fontselect',
      'galleryHandler',
      'handlebars',
      'handlebarshelpers',
      'jszip',
      'SliderBar',
      'storage',
      'toastify',
      'PixelPal'
    ];

    var templates = [
      'addMotiveElementDialog',
      'designerUI',
      'designstorage',
      'dialogCenterbox',
      'requestConsent',
      'alert'
    ];

    var stylesheets = [
      '2ddesigner',
      'ButtonBar',
      'fontselect',
      'SliderBar',
      'starshine',
      'toastify'
    ]

    var totals = {};

    var progress = (url, loaded) => {
      totals[url] = loaded;
      loaded = 0;
      for (url in totals) {
        loaded += totals[url];
      }
      const percentage = parseInt(loaded * 100 / totalpreloadsize);
      document.querySelector('.splash .inner .progressbar .indicator').style.width = `${percentage}%`;
    }

    var getScript = (url, callback) => {
      const el = document.createElement('script');
      el.type = 'text/javascript';
      const r = new XMLHttpRequest();
      r.open('GET', url + '?v=' + version);
      r.addEventListener('load', () => {
        el.src = url;
        document.body.append(el);
        callback();
      });
      r.addEventListener('progress', evt => {
        progress(evt.srcElement.responseURL, evt.loaded)
      })
      r.send();
    }

    var getTemplate = (url, callback) => {
      const el = document.createElement('script');
      el.type = 'text/x-handlebars-template';
      const r = new XMLHttpRequest();
      r.open('GET', url + '?v=' + version);
      r.addEventListener('load', () => {
        el.innerHTML = r.responseText;
        document.body.append(el);
        callback();
      });
      r.addEventListener('progress', evt => {
        progress(evt.srcElement.responseURL, evt.loaded)
      })
      r.send();
    }

    var getStyleSheet = (url, callback) => {
      const el = document.createElement('link');
      el.rel = "stylesheet";
      const r = new XMLHttpRequest();
      r.open('GET', url + '?v=' + version);
      r.addEventListener('load', () => {
        el.href = url;
        document.body.append(el);
        callback();
      });
      r.addEventListener('progress', evt => {
        progress(evt.srcElement.responseURL, evt.loaded)
      })
      r.send();
    }

    var getIcon = (url, callback) => {
      const loader = new XMLHttpRequest();
      loader.open('GET', url + '?v=' + version);
      loader.addEventListener('load', () => callback());
      loader.addEventListener('progress', evt => {
        progress(evt.srcElement.responseURL, evt.loaded);
      })
      loader.send();
    }

    document.addEventListener('readystatechange', () => {
      if (document.readyState == 'complete') {
        for (const btn of document.querySelectorAll('.js-cfg-group.d-none button.js-cfg-next')) {
          btn.click();
        }
      }
    })

    document.getElementById('startdesigner').addEventListener('click', evt => {
      evt.preventDefault();
      evt.target.blur();
      if (window.designer) {
        window.designer.load(kArtikel)
          .then(() => window.designer.show())
          .catch(console.error);
      } else {
        document.querySelector('html').classList.add('designer');
        const splash = document.createElement('div');
        const inner = document.createElement('div');
        inner.classList.add('inner');
        inner.innerHTML = splashLogo ? splashLogo : `<svg version="1.0" xmlns="http://www.w3.org/2000/svg" viewbox="0 0 500 500" width="250" height="250">
          <g fill="#1d3661" stroke="#1d3661">
            <path d="M0 0 L500 0 500 50 50 50 50 450 500 450 500 500 0 500" />
            <path d="M100 100 L150 100 150 400 100 400" />
            <path d="M200 100 L350 100 350 350 400 350 400 100 450 100 450 400 300 400 300 150 250 150 250 400 200 400" />
          </g>
        </svg>
        <div class="shine"></div>`;
        const progressBar = document.createElement('div');
        progressBar.classList.add('progressbar');
        const progressIndicator = document.createElement('div');
        progressIndicator.classList.add('indicator');
        progressBar.append(progressIndicator);
        inner.append(progressBar);
        splash.appendChild(inner);
        splash.classList.add('splash');
        document.body.appendChild(splash);
        splash.classList.add('show');
        const loaders = scripts.map(script => new Promise(resolve => {
            getScript(`${assetpath}js/${script}.js`, resolve)
          }))
          .concat(templates.map(template => new Promise(resolve => {
            getTemplate(`${assetpath}template/hbs/${template}.hbs`, resolve)
          })))
          .concat(stylesheets.map(stylesheet => new Promise(resolve => {
            getStyleSheet(`${assetpath}css/${stylesheet}.css`, resolve)
          })))
          .concat(svgIcons.map(iconName => new Promise(resolve => {
            getIcon(`${assetpath}img/${iconName}.svg`, resolve)
          })));
        Promise.all(loaders)
          .then(() => new Promise(resolve => getScript(`${assetpath}js/2ddesigner.js`, resolve)))
          .then(() => window.waitForObject('fabric'))
          .then(() => new Promise(resolve => getScript(`${assetpath}js/fabric-history.js`, resolve)))
          .then(() => window.waitForObject('TwoDDesigner'))
          .then(() => {
            window.designer = new TwoDDesigner(assetpath, lang, svgIcons, fontPath);
            window.designer.load(kArtikel)
              .then(() => window.designer.show())
              .then(window.waitFor('#designerUI'))
              .then(() => setTimeout(() => document.querySelector('.splash').remove(), 250))
              .catch(console.error);
          });
      }
    });
  {/literal}
</script>
<script src="{$assetpath}js/cin_extensions.js?v={$pluginversion}"></script>
<div class="fontloader"></div>
<div class="dpireference"></div>
